@@ -55,15 +55,15 @@ class PraatLoader:
 
     def run_script(self,name,args):
         if self.debug:
-            updatelog('%s' % name)
+            self.updatelog('%s' % name)
         com = [self.praat, os.path.join(self.script_dir,name)] + map(str,args)
         if self.debug:
-            updatelog('%s' % str(com))
+            self.updatelog('%s' % str(com))
         p = subprocess.Popen(com,stdout=subprocess.PIPE,stderr=subprocess.PIPE,stdin=subprocess.PIPE)
         stdout, stderr = p.communicate()
         if self.debug:
-            updatelog('stdout: %s' % str(stdout))
-            updatelog('stderr: %s' % str(stderr))
+            self.updatelog('stdout: %s' % str(stdout))
+            self.updatelog('stderr: %s' % str(stderr))
         return stdout
 
 
